<?php
/**
 * Functions
 *
 * @package wp-fail2ban-addon-gravity-forms
 * @since 1.1.0
 */
namespace com\wp_fail2ban\addons\GravityForms;

defined('ABSPATH') or exit;

/**
 * Register plugin messages with WP fail2ban
 *
 * @since 1.0.0
 *
 * @return void
 *
 * @wp-f2b-extra \(WPf2b\+\+/gravityforms\) Spam form submission
 */
function wp_fail2ban_register_plugin()
{
    try {
        do_action('wp_fail2ban_register_plugin', 'WPf2b++/gravityforms', '<b>WPf2b++</b> | Gravity Forms');
        do_action('wp_fail2ban_register_message', 'WPf2b++/gravityforms', [
            'slug'          => 'gform_spam',
            'fail'          => 'soft',
            'priority'      => LOG_NOTICE,
            'event_class'   => 'Spam',
            'event_id'      => 0x0001,
            'message'       => 'Spam form submission',
            'vars'          => []
        ]);
    } catch (\RuntimeException $e) {
        // @todo decide what to do
    }
}

/**
 * Fired after an entry is created
 *
 * @since 1.0.0
 *
 * @param array $lead The Entry object
 * @param array $form The Form object
 *
 * @return mixed
 *
 * @SuppressWarnings(PHPMD.UnusedFormalParameter)
 */
function gform_entry_created($lead, $form)
{
    if ('spam' == $lead['status']) {
        try {
            do_action('wp_fail2ban_log_message', 'gform_spam', []);
        } catch (\InvalidArgumentException $e) { // @codeCoverageIgnore
            // failed to register previously
        }
    }
    return $lead;
}
